@@ -2,11 +2,11 @@
  * File: chat.c
  * Author: Justin Zaun
  * Project: GGZ GTK Client
- * $Id: chat.c,v 1.54 2003/05/09 23:11:58 dr_maux Exp $
+ * $Id: chat.c 7740 2006-01-07 04:03:54Z jdorje $
  *
  * This file contains all functions that are chat related.
  *
- * Copyright (C) 2000 Justin Zaun.
+ * Copyright (C) 2000-2005 GGZ Development Team.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,11 +31,22 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <strings.h> /* For strcasecmp */
 #include <gtk/gtk.h>
 #include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
+#ifdef HAVE_SYS_SOCKET_H
+#  include <sys/socket.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
+#  include <netinet/in.h>
+#endif
+#ifdef HAVE_ARPA_INET_H
+#  include <arpa/inet.h>
+#endif
+#ifdef HAVE_WINSOCK_H
+#  include <winsock.h>
+#endif
+
 #include <glib.h>
 
 #include "chat.h"
@@ -65,7 +76,7 @@ static void chat_help(GGZServer *server, const gchar *message);
 static void chat_list_friend(GGZServer *server, const gchar *message);
 static void chat_list_ignore(GGZServer *server, const gchar *message);
 
-struct {
+static struct {
 	const char *cmd;
 	void (*func)(GGZServer *server, const gchar *message);
 	const char *help;
@@ -124,10 +135,10 @@ GdkColor ColorBlack = {0, 0x0000, 0x0000, 0x0000};
  * color in chat and ingnored people's chats don't show
  * up at all.
  */
-struct chatinfo {
+static struct chatinfo {
 	GArray *friends;
 	GArray *ignore;
-}chatinfo;
+} chatinfo;
 
 /* chat_init() - setup chatinfo and allocates colors
  *
@@ -164,30 +175,29 @@ void chat_init(void)
 static void chat_allocate_colors(void)
 {
 	gint i;
-        /* Allocate standared colors */
-        if (!colors[0].pixel)        /* don't do it again */
-        {
-                for (i = 0; i < 20; i++)
-                {
+        /* Allocate standared colors (just once)*/
+        if (!colors[0].pixel) {
+                for (i = 0; i < 20; i++) {
                         colors[i].pixel = (gulong) ((colors[i].red & 0xff00) * 256 +
                                         (colors[i].green & 0xff00) +
                                         (colors[i].blue & 0xff00) / 256);
-                        if (!gdk_color_alloc (gdk_colormap_get_system(),
-                            &colors[i]))
+                        if (!gdk_colormap_alloc_color(gdk_colormap_get_system(),
+						      &colors[i],
+						      FALSE, TRUE))
                                 g_error("*** GGZ: Couldn't alloc color\n");
                 }
         }
         ColorBlack.pixel = (gulong) ((ColorBlack.red & 0xff00) * 256 +
         			(ColorBlack.green & 0xff00) +
         			(ColorBlack.blue & 0xff00) / 256);
-        if (!gdk_color_alloc (gdk_colormap_get_system(),
-        	&ColorBlack))
+        if (!gdk_colormap_alloc_color(gdk_colormap_get_system(),
+				      &ColorBlack, FALSE, TRUE))
         	g_error("*** GGZ: Couldn't alloc color\n");
         ColorWhite.pixel = (gulong) ((ColorWhite.red & 0xff00) * 256 +
         			(ColorWhite.green & 0xff00) +
         			(ColorWhite.blue & 0xff00) / 256);
-        if (!gdk_color_alloc (gdk_colormap_get_system(),
-        	&ColorWhite))
+        if (!gdk_colormap_alloc_color(gdk_colormap_get_system(),
+				      &ColorWhite, FALSE, TRUE))
         	g_error("*** GGZ: Couldn't alloc color\n");
 }
 
@@ -212,7 +222,7 @@ void chat_display_server(GGZChatType type,
 	if (sender && chat_is_ignore(sender))
 		return;
 
-        tmp = gtk_object_get_data(GTK_OBJECT(win_main), "xtext_custom");
+        tmp = g_object_get_data(G_OBJECT(win_main), "xtext_custom");
 
 	switch (type) {
 	case GGZ_CHAT_UNKNOWN:
@@ -227,11 +237,7 @@ void chat_display_server(GGZChatType type,
 			m = g_strdup_printf(_("You have received an "
 					      "unknown message from %s."),
 					    sender);
-#ifdef GTK2
-			gtk_xtext_append_indent(GTK_XTEXT(tmp)->buffer,
-#else
-			gtk_xtext_append_indent(GTK_XTEXT(tmp),
-#endif
+			gtk_xtext_append_indent(tmp->buffer,
 						name, strlen(name),
 						m, strlen(m));
 			g_free(m);
@@ -243,11 +249,7 @@ void chat_display_server(GGZChatType type,
 	case GGZ_CHAT_TABLE:
 		if (!strncasecmp(message, "/me ", 4)) {
 			name = g_strdup_printf("%s %s", sender, message+4);
-#ifdef GTK2
-			gtk_xtext_append_indent(GTK_XTEXT(tmp)->buffer,
-#else
-			gtk_xtext_append_indent(GTK_XTEXT(tmp),
-#endif
+			gtk_xtext_append_indent(tmp->buffer,
 						"*", 1, name, strlen(name));
 			g_free(name);
 		} else {
@@ -263,16 +265,10 @@ void chat_display_server(GGZChatType type,
 					       chat_get_color(sender, message),
 					       sender,
 					       bracketr);
-#ifdef GTK2
-			gtk_xtext_append_indent(GTK_XTEXT(tmp)->buffer,
+			gtk_xtext_append_indent(tmp->buffer,
 						name, strlen(name),
 						(char*)message,
 						strlen(message));
-#else
-			gtk_xtext_append_indent(GTK_XTEXT(tmp),
-						name, strlen(name),
-						message, strlen(message));
-#endif
 			g_free(name);
 		}
 		if (ggzcore_conf_read_int("CHAT", "RSYNTH", FALSE)) {
@@ -287,30 +283,18 @@ void chat_display_server(GGZChatType type,
 		name = g_strdup_printf(">\003%s%s\003<",
 				       chat_get_color(sender, message),
 				       sender);
-#ifdef GTK2
-		gtk_xtext_append_indent(GTK_XTEXT(tmp)->buffer,
+		gtk_xtext_append_indent(tmp->buffer,
 					name, strlen(name),
 					(char*)message, strlen(message));
-#else
-		gtk_xtext_append_indent(GTK_XTEXT(tmp),
-					name, strlen(name),
-					message, strlen(message));
-#endif
 		g_free(name);
 		break;
 	case GGZ_CHAT_ANNOUNCE:
 		name = g_strdup_printf("[\003%s%s\003]",
 				       chat_get_color(sender, message),
 				       sender);
-#ifdef GTK2
-		gtk_xtext_append_indent(GTK_XTEXT(tmp)->buffer,
+		gtk_xtext_append_indent(tmp->buffer,
 					name, strlen(name),
 					(char*)message, strlen(message));
-#else
-		gtk_xtext_append_indent(GTK_XTEXT(tmp),
-					name, strlen(name),
-					message, strlen(message));
-#endif
 		g_free(name);
 		break;
 	case GGZ_CHAT_BEEP:
@@ -331,43 +315,25 @@ void chat_display_local(LocalChatType type,
         GtkXText *tmp;
 	gchar *name;
 
-        tmp = gtk_object_get_data(GTK_OBJECT(win_main), "xtext_custom");
+        tmp = g_object_get_data(G_OBJECT(win_main), "xtext_custom");
 
 	switch (type) {
 	case CHAT_SEND_PERSONAL:
 		name = g_strdup_printf("--> %s", target);
-#ifdef GTK2
-		gtk_xtext_append_indent(GTK_XTEXT(tmp)->buffer,
+		gtk_xtext_append_indent(tmp->buffer,
 					name, strlen(name),
 					(char*)message, strlen(message));
-#else
-		gtk_xtext_append_indent(GTK_XTEXT(tmp),
-					name, strlen(name),
-					message, strlen(message));
-#endif
 		g_free(name);
 		break;
 	case CHAT_LOCAL_NORMAL:
-#ifdef GTK2
-		gtk_xtext_append_indent(GTK_XTEXT(tmp)->buffer,
+		gtk_xtext_append_indent(tmp->buffer,
 					"---", 3,
 					(char*)message, strlen(message));
-#else
-		gtk_xtext_append_indent(GTK_XTEXT(tmp),
-					"---", 3,
-					message, strlen(message));
-#endif
 		break;
 	case CHAT_LOCAL_HIGH:
-#ifdef GTK2
-		gtk_xtext_append_indent(GTK_XTEXT(tmp)->buffer,
+		gtk_xtext_append_indent(tmp->buffer,
 					"***", 3,
 					(char*)message, strlen(message));
-#else
-		gtk_xtext_append_indent(GTK_XTEXT(tmp),
-					"***", 3,
-					message, strlen(message));
-#endif
 		break;
 
 	}
@@ -521,25 +487,36 @@ static void chat_send_beep(GGZServer *server, const gchar *message)
  *
  * Recieves:
  * 	gchar *player	: The players username
+ *      int from_room   : the room the player is coming from (or -1/-2)
  *
  * Returns:
  */
 
-void chat_enter(const gchar *player)
+void chat_enter(const gchar *player, int from_room)
 {
-        GtkEntry *tmp = NULL;
+        GtkXText *tmp = NULL;
 
         if( !ggzcore_conf_read_int("CHAT", "IGNORE", FALSE) )
         {
-	        tmp = gtk_object_get_data(GTK_OBJECT(win_main), "xtext_custom");
-#ifdef GTK2
-		gtk_xtext_append_indent(GTK_XTEXT(tmp)->buffer,
-					"-->", 3,
-					(char*)player, strlen(player));
-#else
-        	gtk_xtext_append_indent(GTK_XTEXT(tmp),
-					"-->", 3, player, strlen(player));
-#endif
+		char message[256];
+		GGZRoom *room = ggzcore_server_get_nth_room(server, from_room);
+
+		if (from_room == -1) {
+			/* Just entering server. */
+			snprintf(message, sizeof(message),
+				 _("%s (logged on)"), player);
+		} else if (room) {
+			snprintf(message, sizeof(message),
+				 "%s (from %s)", player,
+				 ggzcore_room_get_name(room));
+		} else {
+			/* No data. */
+			snprintf(message, sizeof(message), "%s", player);
+		}
+
+	        tmp = g_object_get_data(G_OBJECT(win_main), "xtext_custom");
+		gtk_xtext_append_indent(tmp->buffer,
+					"-->", 3, message, strlen(message));
 	}
 }
 
@@ -549,25 +526,36 @@ void chat_enter(const gchar *player)
  *
  * Recieves:
  * gchar	*player	: The players username
+ * int          to_room : The room the player is going to (or -1/-2)
  *
  * Returns:
  */
 
-void chat_part(const gchar *player)
+void chat_part(const gchar *player, int to_room)
 {
-        GtkEntry *tmp = NULL;
+        GtkXText *tmp = NULL;
 
         if( !ggzcore_conf_read_int("CHAT", "IGNORE", FALSE) )
         {
-	        tmp = gtk_object_get_data(GTK_OBJECT(win_main), "xtext_custom");
-#ifdef GTK2
-		gtk_xtext_append_indent(GTK_XTEXT(tmp)->buffer,
-					"<--", 3,
-					(char*)player, strlen(player));
-#else
-        	gtk_xtext_append_indent(GTK_XTEXT(tmp),
-					"<--", 3, player, strlen(player));
-#endif
+		char message[256];
+		GGZRoom *room = ggzcore_server_get_nth_room(server, to_room);
+
+		if (to_room == -1) {
+			/* Leaving server. */
+			snprintf(message, sizeof(message),
+				 _("%s (logged off)"), player);
+		} else if (room) {
+			snprintf(message, sizeof(message),
+				 "%s (to %s)", player,
+				 ggzcore_room_get_name(room));
+		} else {
+			/* No data. */
+			snprintf(message, sizeof(message), "%s", player);
+		}
+
+	        tmp = g_object_get_data(G_OBJECT(win_main), "xtext_custom");
+		gtk_xtext_append_indent(tmp->buffer,
+					"<--", 3, message, strlen(message));
 	}
 }
 
@@ -616,7 +604,11 @@ int chat_checkurl(GtkXText *xtext, char *word)
 {
 	char *at, *dot;
 	int i, dots;
-	int len = strlen (word);
+	int len;
+
+	if(!word) return 0;
+	
+	len = strlen (word);
 
 	/* Check for URLs */
 	if (!strncasecmp (word, "ftp.", 4))
@@ -721,7 +713,7 @@ void chat_word_clicked(GtkXText *xtext, char *word,
 static const gchar *chat_get_color(const gchar *name, const gchar *msg)
 {
 	unsigned int pos;
-	char *srv_handle;
+	const char *srv_handle;
 	int c;
 	static gchar color[16];
 
