@@ -2,7 +2,7 @@
  * File: client.h
  * Author: Justin Zaun
  * Project: GGZ GTK Client
- * $Id: client.h,v 1.10 2002/11/04 01:47:46 jdorje Exp $
+ * $Id: client.h 7737 2006-01-06 22:34:17Z jdorje $
  *
  * This is the main program body for the GGZ client
  *
@@ -23,6 +23,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#include <ggzcore.h>
+
 void client_join_table(void);
 
 void client_start_table_join(void);
@@ -33,3 +35,6 @@ GtkWidget* create_win_main (void);
 #define DEFAULT_FONT "-*-fixed-medium-r-semicondensed--*-120-*-*-c-*-iso8859-1"
 
 extern GtkWidget *win_main;
+extern void (*connected_cb)(GGZServer *server);
+extern void (*launched_cb)(void);
+extern char *embedded_protocol_engine, *embedded_protocol_version;
