@@ -3,7 +3,7 @@
  * Author: Brent Hendricks
  * Project: GGZ Text Client 
  * Date: 3/1/01
- * $Id: game.h,v 1.6 2002/11/04 00:31:34 jdorje Exp $
+ * $Id: game.h 7726 2006-01-06 01:08:10Z jdorje $
  *
  * Functions for handling game events
  *
@@ -31,7 +31,7 @@
  *
  *  @param spectating 1 if we're spectating, 0 if we're joining
  */
-int game_init(int spectating);
+int game_initialize(int spectating);
 
 int game_launch(void);
 
@@ -42,5 +42,3 @@ void game_quit(void);
 void game_destroy(void);
 
 int game_play(void);
-
-extern GGZGame *game;
