@@ -2,7 +2,7 @@
  * File: client.c
  * Author: Justin Zaun
  * Project: GGZ GTK Client
- * $Id: login.h,v 1.9 2002/11/04 00:31:34 jdorje Exp $
+ * $Id: login.h 7737 2006-01-06 22:34:17Z jdorje $
  *
  * This is the main program body for the GGZ client
  *
@@ -23,10 +23,15 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-void login_create_or_raise(void);
+#include "server.h"
+
 void login_connect_failed(void);
-void login_failed(void);
+void login_failed(const GGZErrorEventData * error);
 void login_destroy(void);
-void login_goto_server(gchar *server_url);
+void login_goto_server(const gchar * server_url);
+
+void login_set_entries(Server server);
 
 extern GtkWidget *login_dialog;
+extern gchar *option_log;
+
