@@ -3,7 +3,7 @@
  * Author: GGZ Dev Team
  * Project: GGZ Text Client 
  * Date: 11/5/2002
- * $Id: pick_module.h,v 1.1 2002/11/05 09:18:18 jdorje Exp $
+ * $Id: pick_module.h 6089 2004-07-12 16:50:18Z josef $
  *
  * Dialog window to pick a module for your game
  *
@@ -24,5 +24,5 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-int ask_user_to_pick_module(GGZModule **modules, int *preserve);
+int ask_user_to_pick_module(GGZModule **modules, int *modulenumbers, int *preserve);
 void cancel_module_picking(void);
